@@ -31,15 +31,12 @@ setMethod(
     method <- match.arg(method, several.ok = FALSE)
     arkhe::assert_lower(s0, s1, strict = FALSE)
     arkhe::assert_lower(t0, t1, strict = FALSE)
+    arkhe::assert_lower(from, to, strict = TRUE)
 
     ## Get data
     n_site <- nrow(object)
     n_type <- ncol(object)
     span <- to - from
-    if (span <= 0) {
-      msg <- "The duration of the period of interest cannot be negative (%g)!"
-      stop(sprintf(msg, span), call. = FALSE)
-    }
 
     ## Number of periods (rounded toward the smallest integer)
     n_periode <- ceiling(span / step)
@@ -71,7 +68,7 @@ setMethod(
     k_site <- seq_len(n_site)
     k_type <- seq_len(n_type)
 
-    progress_bar <- interactive() && progress
+    progress_bar <- interactive() && isTRUE(progress)
     if (progress_bar) pbar <- utils::txtProgressBar(max = n_site, style = 3)
 
     for (i in k_site) {
