@@ -2,8 +2,6 @@
 #' @include AllGenerics.R
 NULL
 
-# TODO: use aion::calendar_year() once released.
-
 #' @export
 #' @method summary EventDate
 summary.EventDate <- function(object, ...) {
@@ -20,7 +18,7 @@ setMethod("summary", c(object = "EventDate"), summary.EventDate)
 coef.EventDate <- function(object, calendar = NULL, ...) {
   z <- stats::coef(object@model, ...)
   if (is.null(calendar)) return(z)
-  unclass(z) / calendar@year # Approximate
+  unclass(z) / aion::calendar_year(calendar) # Approximate
 }
 
 #' @export
@@ -46,7 +44,7 @@ setMethod("fitted", "EventDate", fitted.EventDate)
 residuals.EventDate <- function(object, calendar = NULL, ...) {
   z <- stats::residuals(object@model, ...)
   if (is.null(calendar)) return(z)
-  unclass(z) / calendar@year # Approximate
+  unclass(z) / aion::calendar_year(calendar) # Approximate
 }
 
 #' @export
@@ -59,7 +57,7 @@ setMethod("residuals", "EventDate", residuals.EventDate)
 sigma.EventDate <- function(object, calendar = NULL, ...) {
   z <- stats::sigma(object@model, ...)
   if (is.null(calendar)) return(z)
-  unclass(z) / calendar@year # Approximate
+  unclass(z) / aion::calendar_year(calendar) # Approximate
 }
 
 #' @export
