@@ -2,8 +2,7 @@
   op <- options()
   op.kairos <- list(
     kairos.verbose = interactive(),
-    kairos.progress = interactive(),
-    kairos.calendar = aion::CE()
+    kairos.progress = interactive()
   )
   toset <- !(names(op.kairos) %in% names(op))
   if(any(toset)) options(op.kairos[toset])
